[Cmake-commits] CMake branch, master, updated. v3.8.0-rc1-41-g6c8d659

2017-02-10 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  6c8d65963104451b15aa331a6914173af42a224c (commit)
  from  ee3295e91740033ebe9d9a0c800c0a3070108624 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=6c8d65963104451b15aa331a6914173af42a224c
commit 6c8d65963104451b15aa331a6914173af42a224c
Author: Kitware Robot 
AuthorDate: Sat Feb 11 00:01:08 2017 -0500
Commit: Kitware Robot 
CommitDate: Sat Feb 11 00:01:08 2017 -0500

CMake Nightly Date Stamp

diff --git a/Source/CMakeVersion.cmake b/Source/CMakeVersion.cmake
index 070abf8..78cee13 100644
--- a/Source/CMakeVersion.cmake
+++ b/Source/CMakeVersion.cmake
@@ -1,5 +1,5 @@
 # CMake version number components.
 set(CMake_VERSION_MAJOR 3)
 set(CMake_VERSION_MINOR 8)
-set(CMake_VERSION_PATCH 20170210)
+set(CMake_VERSION_PATCH 20170211)
 #set(CMake_VERSION_RC 1)

---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.8.0-rc1-90-g4c53c29

2017-02-10 Thread Daniel Pfeifer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  4c53c29d86e7dc4c580fb5b7c8f06551934ae03c (commit)
   via  4ff5dce9f8be34d556f1fb98272a8654b1f6c5bb (commit)
   via  934ac7916e4e4df6ef55441d58fd1c310e4ad9f1 (commit)
   via  717491dd7d4a886d484025fd9002df44458117b5 (commit)
   via  b75e7691425d4cb658f3b0981fdbfbc25dedfb43 (commit)
   via  17926f29cecc7574c9173ff06f5e3d0e4e250b02 (commit)
   via  c1bfff2e72bd673e7b7bebddf58c7ea508bf4196 (commit)
  from  fe4c8e497ce4eb67bd14187f8729710a72cfe37a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=4c53c29d86e7dc4c580fb5b7c8f06551934ae03c
commit 4c53c29d86e7dc4c580fb5b7c8f06551934ae03c
Merge: fe4c8e4 4ff5dce
Author: Daniel Pfeifer 
AuthorDate: Fri Feb 10 18:21:19 2017 -0500
Commit: CMake Topic Stage 
CommitDate: Fri Feb 10 18:21:19 2017 -0500

Merge topic 'command-cleanup' into next

4ff5dce9 cmCommands: add commands directly to cmState
934ac791 split Default commands into Scripting and Project
717491dd cmDeprecatedCommand: extract policy checking from cmCommand
b75e7691 cmCommand: Don't prefix error message with command name
17926f29 cmCommand: make noncopyable
c1bfff2e cmCommand: remove member Helper


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=4ff5dce9f8be34d556f1fb98272a8654b1f6c5bb
commit 4ff5dce9f8be34d556f1fb98272a8654b1f6c5bb
Author: Daniel Pfeifer 
AuthorDate: Fri Jan 20 22:40:16 2017 +0100
Commit: Daniel Pfeifer 
CommitDate: Sat Feb 11 00:20:22 2017 +0100

cmCommands: add commands directly to cmState

diff --git a/Source/cmCommands.cxx b/Source/cmCommands.cxx
index bc24234..9ff395a 100644
--- a/Source/cmCommands.cxx
+++ b/Source/cmCommands.cxx
@@ -1,6 +1,7 @@
 /* Distributed under the OSI-approved BSD 3-Clause License.  See accompanying
file Copyright.txt or https://cmake.org/licensing for details.  */
 #include "cmCommands.h"
+#include "cmState.h"
 
 #include "cmAddCustomCommandCommand.h"
 #include "cmAddCustomTargetCommand.h"
@@ -105,170 +106,162 @@
 #include "cmWriteFileCommand.h"
 #endif
 
-std::vector GetScriptingCommands()
+void GetScriptingCommands(cmState* state)
 {
-  std::vector commands;
+  state->AddCommand(new cmBreakCommand);
+  state->AddCommand(new cmCMakeMinimumRequired);
+  state->AddCommand(new cmCMakePolicyCommand);
+  state->AddCommand(new cmConfigureFileCommand);
+  state->AddCommand(new cmContinueCommand);
+  state->AddCommand(new cmExecProgramCommand);
+  state->AddCommand(new cmExecuteProcessCommand);
+  state->AddCommand(new cmFileCommand);
+  state->AddCommand(new cmFindFileCommand);
+  state->AddCommand(new cmFindLibraryCommand);
+  state->AddCommand(new cmFindPackageCommand);
+  state->AddCommand(new cmFindPathCommand);
+  state->AddCommand(new cmFindProgramCommand);
+  state->AddCommand(new cmForEachCommand);
+  state->AddCommand(new cmFunctionCommand);
+  state->AddCommand(new cmGetCMakePropertyCommand);
+  state->AddCommand(new cmGetDirectoryPropertyCommand);
+  state->AddCommand(new cmGetFilenameComponentCommand);
+  state->AddCommand(new cmGetPropertyCommand);
+  state->AddCommand(new cmIfCommand);
+  state->AddCommand(new cmIncludeCommand);
+  state->AddCommand(new cmListCommand);
+  state->AddCommand(new cmMacroCommand);
+  state->AddCommand(new cmMakeDirectoryCommand);
+  state->AddCommand(new cmMarkAsAdvancedCommand);
+  state->AddCommand(new cmMathCommand);
+  state->AddCommand(new cmMessageCommand);
+  state->AddCommand(new cmOptionCommand);
+  state->AddCommand(new cmParseArgumentsCommand);
+  state->AddCommand(new cmReturnCommand);
+  state->AddCommand(new cmSeparateArgumentsCommand);
+  state->AddCommand(new cmSetCommand);
+  state->AddCommand(new cmSetDirectoryPropertiesCommand);
+  state->AddCommand(new cmSetPropertyCommand);
+  state->AddCommand(new cmSiteNameCommand);
+  state->AddCommand(new cmStringCommand);
+  state->AddCommand(new cmUnsetCommand);
+  state->AddCommand(new cmWhileCommand);
 
-  commands.push_back(new cmBreakCommand);
-  commands.push_back(new cmCMakeMinimumRequired);
-  commands.push_back(new cmCMakePolicyCommand);
-  commands.push_back(new cmConfigureFileCommand);
-  commands.push_back(new cmContinueCommand);
-  commands.push_back(new cmExecProgramCommand);
-  commands.push_back(new cmExecuteProcessCommand);
-  commands.push_back(new cmFileCommand);
-  commands.push_back(new cmFindFileCommand);
-  commands.push_back(new cmFindLibraryCommand);
-  commands.push_back(new cmFindPackageCommand);
-  commands.push_back(new cmFindPathCommand);
-  commands.push_back(new cmFindProgramCommand);
-  commands.push_

[Cmake-commits] CMake branch, next, updated. v3.8.0-rc1-83-gfe4c8e4

2017-02-10 Thread Daniel Pfeifer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  fe4c8e497ce4eb67bd14187f8729710a72cfe37a (commit)
   via  c3800e54583208ac4a6435884bb8832e72af3183 (commit)
  from  97eb120fd3b755ceb24da8ab159ecd68a8f62330 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=fe4c8e497ce4eb67bd14187f8729710a72cfe37a
commit fe4c8e497ce4eb67bd14187f8729710a72cfe37a
Merge: 97eb120 c3800e5
Author: Daniel Pfeifer 
AuthorDate: Fri Feb 10 17:05:32 2017 -0500
Commit: CMake Topic Stage 
CommitDate: Fri Feb 10 17:05:32 2017 -0500

Merge topic 'erase-if' into next

c3800e54 cmAlgorithms: add cmEraseIf function


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=c3800e54583208ac4a6435884bb8832e72af3183
commit c3800e54583208ac4a6435884bb8832e72af3183
Author: Daniel Pfeifer 
AuthorDate: Fri Feb 10 23:04:32 2017 +0100
Commit: Daniel Pfeifer 
CommitDate: Fri Feb 10 23:04:32 2017 +0100

cmAlgorithms: add cmEraseIf function

diff --git a/Source/cmAlgorithms.h b/Source/cmAlgorithms.h
index 7c683ad..f5469e5 100644
--- a/Source/cmAlgorithms.h
+++ b/Source/cmAlgorithms.h
@@ -101,6 +101,12 @@ FwdIt cmRotate(FwdIt first, FwdIt middle, FwdIt last)
   return first;
 }
 
+template 
+void cmEraseIf(Container& cont, Predicate pred)
+{
+  cont.erase(std::remove_if(cont.begin(), cont.end(), pred), cont.end());
+}
+
 namespace ContainerAlgorithms {
 
 template 
diff --git a/Source/cmGlobalVisualStudio14Generator.cxx 
b/Source/cmGlobalVisualStudio14Generator.cxx
index 81c305c..d2ac36b 100644
--- a/Source/cmGlobalVisualStudio14Generator.cxx
+++ b/Source/cmGlobalVisualStudio14Generator.cxx
@@ -238,8 +238,7 @@ std::string 
cmGlobalVisualStudio14Generator::GetWindows10SDKVersion()
 
   // Skip SDKs that do not contain  because that indicates that
   // only the UCRT MSIs were installed for them.
-  sdks.erase(std::remove_if(sdks.begin(), sdks.end(), NoWindowsH()),
- sdks.end());
+  cmEraseIf(sdks, NoWindowsH());
 
   if (!sdks.empty()) {
 // Only use the filename, which will be the SDK version.
diff --git a/Source/cmLocalUnixMakefileGenerator3.cxx 
b/Source/cmLocalUnixMakefileGenerator3.cxx
index 41a4caf..4388e75 100644
--- a/Source/cmLocalUnixMakefileGenerator3.cxx
+++ b/Source/cmLocalUnixMakefileGenerator3.cxx
@@ -1864,10 +1864,7 @@ void 
cmLocalUnixMakefileGenerator3::WriteDependLanguageInfo(
 std::string binaryDir = this->GetState()->GetBinaryDirectory();
 if (this->Makefile->IsOn("CMAKE_DEPENDS_IN_PROJECT_ONLY")) {
   const char* sourceDir = this->GetState()->GetSourceDirectory();
-  std::vector::iterator itr =
-std::remove_if(includes.begin(), includes.end(),
-   ::NotInProjectDir(sourceDir, binaryDir));
-  includes.erase(itr, includes.end());
+  cmEraseIf(includes, ::NotInProjectDir(sourceDir, binaryDir));
 }
 for (std::vector::iterator i = includes.begin();
  i != includes.end(); ++i) {
diff --git a/Source/cmMakefile.cxx b/Source/cmMakefile.cxx
index bfe46ae..618f694 100644
--- a/Source/cmMakefile.cxx
+++ b/Source/cmMakefile.cxx
@@ -653,21 +653,12 @@ void cmMakefile::FinalPass()
   // we don't want cmake to re-run if a configured file is created and deleted
   // during processing as that would make it a transient file that can't
   // influence the build process
-
-  // remove_if will move all items that don't have a valid file name to the
-  // back of the vector
-  std::vector::iterator new_output_files_end = std::remove_if(
-this->OutputFiles.begin(), this->OutputFiles.end(), file_not_persistent());
-  // we just have to erase all items at the back
-  this->OutputFiles.erase(new_output_files_end, this->OutputFiles.end());
+  cmEraseIf(this->OutputFiles, file_not_persistent());
 
   // if a configured file is used as input for another configured file,
   // and then deleted it will show up in the input list files so we
   // need to scan those too
-  std::vector::iterator new_list_files_end = std::remove_if(
-this->ListFiles.begin(), this->ListFiles.end(), file_not_persistent());
-
-  this->ListFiles.erase(new_list_files_end, this->ListFiles.end());
+  cmEraseIf(this->ListFiles, file_not_persistent());
 }
 
 // Generate the output file
diff --git a/Source/cmNinjaNormalTargetGenerator.cxx 
b/Source/cmNinjaNormalTargetGenerator.cxx
index b172478..9bf0ccd 100644
--- a/Source/cmNinjaNormalTargetGenerator.cxx
+++ b/Source/cmNinjaNormalTargetGenerator.cxx
@@ -260,12 +260,9 @@ void 
cmNinjaNormalTargetGenerator::WriteDeviceLinkRule(bool useResponseFile)
   rulePlaceholderExpander->ExpandRuleVariables(this->GetLocalGenerator(),

[Cmake-commits] CMake branch, next, updated. v3.8.0-rc1-81-g97eb120

2017-02-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  97eb120fd3b755ceb24da8ab159ecd68a8f62330 (commit)
   via  166b3393875e4f6752907b9b06c2518dce0432e9 (commit)
   via  cbe4d5957b526f9a9bb6954d0c6944ad7642bb90 (commit)
   via  8731701cb636317df2691359361562f32adfe759 (commit)
   via  0ae5386aa953d1670074c2f1bfc9a04ddb382684 (commit)
   via  ce19607fed3990b8e828330e77f09061c99aa113 (commit)
   via  008ed80dcf1d03640879b4168f4fba956aa03196 (commit)
   via  c0d7bb8368c3d157d1a2758b620fc726355e554d (commit)
   via  21a125cdbff24efa746249a3b8ccc6296c5f0aff (commit)
   via  eebb2be8b0db17bb5f760e7fa04c020406e6f6eb (commit)
   via  84f3c87b030037646c1110b1e4237f597ad3dd88 (commit)
  from  36fd53b534c9678996b7bac971ac608cbbd2e910 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=97eb120fd3b755ceb24da8ab159ecd68a8f62330
commit 97eb120fd3b755ceb24da8ab159ecd68a8f62330
Merge: 36fd53b 166b339
Author: Brad King 
AuthorDate: Fri Feb 10 14:02:31 2017 -0500
Commit: CMake Topic Stage 
CommitDate: Fri Feb 10 14:02:31 2017 -0500

Merge topic 'cuda_tests_improve_error_reporting' into next

166b3393 Tests/Cuda: Select a CUDA device supporting compute 3.0
cbe4d595 Tests/Cuda: Return a non-zero code if errors occurred
8731701c Tests/Cuda: Use memory allocated on the GPU in the kernels
0ae5386a Tests/Cuda: Add missing separable compilation property
ce19607f Tests/Cuda: Fix missing CUDA static library at runtime on macOS
008ed80d Tests/Cuda: Output error messages to std::cerr instead of std::cout
c0d7bb83 Tests/Cuda: Print asynchronous error messages, if any
21a125cd Tests/Cuda: Print error message if mixed_kernel failed
eebb2be8 Tests/Cuda: Add identifiers to error messages
84f3c87b Tests/Cuda: Print error message if an error occurred


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=166b3393875e4f6752907b9b06c2518dce0432e9
commit 166b3393875e4f6752907b9b06c2518dce0432e9
Author: Pierre Moreau 
AuthorDate: Wed Feb 8 22:50:58 2017 +0100
Commit: Brad King 
CommitDate: Fri Feb 10 13:47:05 2017 -0500

Tests/Cuda: Select a CUDA device supporting compute 3.0

diff --git a/Tests/Cuda/Complex/dynamic.cu b/Tests/Cuda/Complex/dynamic.cu
index 0206bb4..2b04ac9 100644
--- a/Tests/Cuda/Complex/dynamic.cu
+++ b/Tests/Cuda/Complex/dynamic.cu
@@ -22,6 +22,46 @@ void DetermineIfValidCudaDevice()
 {
 }
 
+EXPORT int choose_cuda_device()
+{
+  int nDevices = 0;
+  cudaError_t err = cudaGetDeviceCount(&nDevices);
+  if (err != cudaSuccess)
+{
+std::cerr << "Failed to retrieve the number of CUDA enabled devices"
+  << std::endl;
+return 1;
+}
+  for (int i = 0; i < nDevices; ++i)
+{
+cudaDeviceProp prop;
+cudaError_t err = cudaGetDeviceProperties(&prop, i);
+if (err != cudaSuccess)
+  {
+  std::cerr << "Could not retrieve properties from CUDA device " << i
+<< std::endl;
+  return 1;
+  }
+if (prop.major >= 4)
+  {
+err = cudaSetDevice(i);
+if (err != cudaSuccess)
+  {
+  std::cout << "Could not select CUDA device " << i << std::endl;
+  }
+else
+  {
+return 0;
+  }
+  }
+}
+
+  std::cout << "Could not find a CUDA enabled card supporting compute >=3.0"
+<< std::endl;
+
+  return 1;
+}
+
 EXPORT void cuda_dynamic_lib_func()
 {
   DetermineIfValidCudaDevice <<<1,1>>> ();
diff --git a/Tests/Cuda/Complex/main.cpp b/Tests/Cuda/Complex/main.cpp
index 92d1fb0..2498235 100644
--- a/Tests/Cuda/Complex/main.cpp
+++ b/Tests/Cuda/Complex/main.cpp
@@ -9,11 +9,17 @@
 #define IMPORT
 #endif
 
+IMPORT int choose_cuda_device();
 IMPORT int call_cuda_seperable_code(int x);
 IMPORT int mixed_launch_kernel(int x);
 
 int main(int argc, char** argv)
 {
+  int ret = choose_cuda_device();
+  if (ret) {
+return 0;
+  }
+
   int r1 = call_cuda_seperable_code(42);
   int r2 = mixed_launch_kernel(42);
   return (r1 == 42 || r2 == 42) ? 1 : 0;

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=cbe4d5957b526f9a9bb6954d0c6944ad7642bb90
commit cbe4d5957b526f9a9bb6954d0c6944ad7642bb90
Author: Pierre Moreau 
AuthorDate: Thu Feb 2 23:12:15 2017 +0100
Commit: Brad King 
CommitDate: Fri Feb 10 13:46:42 2017 -0500

Tests/Cuda: Return a non-zero code if errors occurred

diff --git a/Tests/Cuda/Complex/main.cpp b/Tests/Cuda/Complex/main.cpp
index 5a3f820..92d1fb0 100644
--- a/Tests/Cuda/Complex/main.cpp
+++ b/Tests/Cuda/Complex/main.cpp
@@ -14,7 +14,7 @@ IMPORT int mixed_launch_kernel(int 

[Cmake-commits] CMake branch, next, updated. v3.8.0-rc1-70-g36fd53b

2017-02-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  36fd53b534c9678996b7bac971ac608cbbd2e910 (commit)
   via  ee3295e91740033ebe9d9a0c800c0a3070108624 (commit)
   via  0a30938848518a0e5095a5dd7e4739922a78b743 (commit)
   via  bb72fff2f09ef307b74de35ab00dfc08e6da83ee (commit)
   via  f236c9cff9dcb4d4534e5532a9792e648d48d921 (commit)
  from  f78dfcfd57e10ab8f2d020bfbc462e535918bec0 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=36fd53b534c9678996b7bac971ac608cbbd2e910
commit 36fd53b534c9678996b7bac971ac608cbbd2e910
Merge: f78dfcf ee3295e
Author: Brad King 
AuthorDate: Fri Feb 10 13:36:28 2017 -0500
Commit: Brad King 
CommitDate: Fri Feb 10 13:36:28 2017 -0500

Merge branch 'master' into next


---

Summary of changes:


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.8.0-rc1-38-g0a30938

2017-02-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  0a30938848518a0e5095a5dd7e4739922a78b743 (commit)
   via  9837ed96992a0a5e151c4cb5d4cbe6c7890d7db4 (commit)
  from  bb72fff2f09ef307b74de35ab00dfc08e6da83ee (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=0a30938848518a0e5095a5dd7e4739922a78b743
commit 0a30938848518a0e5095a5dd7e4739922a78b743
Merge: bb72fff 9837ed9
Author: Brad King 
AuthorDate: Fri Feb 10 13:36:14 2017 -0500
Commit: CMake Topic Stage 
CommitDate: Fri Feb 10 13:36:14 2017 -0500

Merge topic 'ExtractGTestMacro'

9837ed96 GoogleTest: Add module to contain gtest_add_tests independently


---

Summary of changes:
 Help/manual/cmake-modules.7.rst|1 +
 Help/module/GoogleTest.rst |1 +
 Help/release/dev/ExtractGTestMacro.rst |5 +++
 Modules/FindGTest.cmake|   60 ++
 Modules/GoogleTest.cmake   |   73 
 5 files changed, 83 insertions(+), 57 deletions(-)
 create mode 100644 Help/module/GoogleTest.rst
 create mode 100644 Help/release/dev/ExtractGTestMacro.rst
 create mode 100644 Modules/GoogleTest.cmake


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.8.0-rc1-40-gee3295e

2017-02-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  ee3295e91740033ebe9d9a0c800c0a3070108624 (commit)
   via  5ba2c9e5e08cb391c366065210a95a46ac74f310 (commit)
  from  0a30938848518a0e5095a5dd7e4739922a78b743 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=ee3295e91740033ebe9d9a0c800c0a3070108624
commit ee3295e91740033ebe9d9a0c800c0a3070108624
Merge: 0a30938 5ba2c9e
Author: Brad King 
AuthorDate: Fri Feb 10 13:36:18 2017 -0500
Commit: CMake Topic Stage 
CommitDate: Fri Feb 10 13:36:18 2017 -0500

Merge topic 'vs-nasm'

5ba2c9e5 VS: Add support for ASM_NASM language

diff --cc Modules/CMakeDetermineASMCompiler.cmake
index 3f18a8c,66bf14b..7d5e2b2
--- a/Modules/CMakeDetermineASMCompiler.cmake
+++ b/Modules/CMakeDetermineASMCompiler.cmake
@@@ -92,9 -92,17 +92,17 @@@ if(NOT CMAKE_ASM${ASM_DIALECT}_COMPILER
set(CMAKE_ASM${ASM_DIALECT}_COMPILER_ID_VENDOR_FLAGS_ARMCC )
set(CMAKE_ASM${ASM_DIALECT}_COMPILER_ID_VENDOR_REGEX_ARMCC "(ARM 
Compiler)|(ARM Assembler)")
  
+   list(APPEND CMAKE_ASM${ASM_DIALECT}_COMPILER_ID_VENDORS NASM)
+   set(CMAKE_ASM${ASM_DIALECT}_COMPILER_ID_VENDOR_FLAGS_NASM "-v")
+   set(CMAKE_ASM${ASM_DIALECT}_COMPILER_ID_VENDOR_REGEX_NASM "(NASM version)")
+ 
+   list(APPEND CMAKE_ASM${ASM_DIALECT}_COMPILER_ID_VENDORS YASM)
+   set(CMAKE_ASM${ASM_DIALECT}_COMPILER_ID_VENDOR_FLAGS_YASM "--version")
+   set(CMAKE_ASM${ASM_DIALECT}_COMPILER_ID_VENDOR_REGEX_YASM "(yasm)")
+ 
include(CMakeDetermineCompilerId)
 -  CMAKE_DETERMINE_COMPILER_ID_VENDOR(ASM${ASM_DIALECT})
 -
 +  set(userflags)
 +  CMAKE_DETERMINE_COMPILER_ID_VENDOR(ASM${ASM_DIALECT} "${userflags}")
  endif()
  
  if(CMAKE_ASM${ASM_DIALECT}_COMPILER_ID)

---

Summary of changes:
 Help/release/dev/vs-nasm.rst |5 ++
 Modules/CMakeDetermineASMCompiler.cmake  |8 ++
 Modules/CMakeDetermineASM_NASMCompiler.cmake |   17 +++-
 Source/cmGlobalVisualStudio10Generator.cxx   |   14 
 Source/cmGlobalVisualStudio10Generator.h |2 +
 Source/cmGlobalVisualStudio7Generator.cxx|1 +
 Source/cmGlobalVisualStudio7Generator.h  |2 +
 Source/cmVS10NASMFlagTable.h |   50 
 Source/cmVisualStudio10TargetGenerator.cxx   |  105 
 Source/cmVisualStudio10TargetGenerator.h |9 ++-
 Source/cmVisualStudio10ToolsetOptions.cxx|1 +
 Source/cmVisualStudioGeneratorOptions.h  |1 +
 Templates/MSBuild/nasm.props.in  |   17 
 Templates/MSBuild/nasm.targets   |   41 ++
 Templates/MSBuild/nasm.xml   |  110 ++
 Tests/CMakeLists.txt |7 +-
 Tests/{VSMASM => VSNASM}/CMakeLists.txt  |6 +-
 Tests/VSNASM/foo.asm |7 ++
 Tests/VSNASM/include/foo-proc.asm|7 ++
 Tests/{VSMASM => VSNASM}/main.c  |0
 20 files changed, 403 insertions(+), 7 deletions(-)
 create mode 100644 Help/release/dev/vs-nasm.rst
 create mode 100644 Source/cmVS10NASMFlagTable.h
 create mode 100644 Templates/MSBuild/nasm.props.in
 create mode 100644 Templates/MSBuild/nasm.targets
 create mode 100644 Templates/MSBuild/nasm.xml
 copy Tests/{VSMASM => VSNASM}/CMakeLists.txt (63%)
 create mode 100644 Tests/VSNASM/foo.asm
 create mode 100644 Tests/VSNASM/include/foo-proc.asm
 copy Tests/{VSMASM => VSNASM}/main.c (100%)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.8.0-rc1-29-gf236c9c

2017-02-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  f236c9cff9dcb4d4534e5532a9792e648d48d921 (commit)
   via  e2ee0971474ce92766f77d77025319ef575aa303 (commit)
  from  46c6489850ca9029bb75d17ed652563fc58a0082 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=f236c9cff9dcb4d4534e5532a9792e648d48d921
commit f236c9cff9dcb4d4534e5532a9792e648d48d921
Merge: 46c6489 e2ee097
Author: Brad King 
AuthorDate: Fri Feb 10 13:36:09 2017 -0500
Commit: CMake Topic Stage 
CommitDate: Fri Feb 10 13:36:09 2017 -0500

Merge topic 'gcc-cpp98'

e2ee0971 g++ knows about C++98 selection flags since at least 3.4


---

Summary of changes:
 Modules/Compiler/GNU-CXX.cmake |3 +--
 1 file changed, 1 insertion(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.8.0-rc1-36-gbb72fff

2017-02-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  bb72fff2f09ef307b74de35ab00dfc08e6da83ee (commit)
   via  d4da4755cdab41679ae7c2fa6ef2984a2d6837ec (commit)
   via  14c771530a12feb4f92fb0ab466b40ff68997b05 (commit)
   via  73ae67006c952b8804f2566e868bc3acf7539857 (commit)
   via  1df9d5f91944e0b5ba00815d55bb7dc545053b4c (commit)
   via  4cc2908fdaaf1ab8afe5c2ae5dbb3401859a9aab (commit)
   via  f4a3290ae7ae096f8b92f7adfba7088e6918bc0b (commit)
  from  f236c9cff9dcb4d4534e5532a9792e648d48d921 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=bb72fff2f09ef307b74de35ab00dfc08e6da83ee
commit bb72fff2f09ef307b74de35ab00dfc08e6da83ee
Merge: f236c9c d4da475
Author: Brad King 
AuthorDate: Fri Feb 10 13:36:11 2017 -0500
Commit: CMake Topic Stage 
CommitDate: Fri Feb 10 13:36:11 2017 -0500

Merge topic 'update-curl'

d4da4755 Help: Add notes for topic 'update-curl'
14c77153 Tests: Fix `file://` URLs given to curl
73ae6700 curl: Fix passing _WINSOCKAPI_ macro to compiler
1df9d5f9 Merge branch 'upstream-curl' into update-curl
4cc2908f curl 2016-12-22 (44b9b4d4)
f4a3290a curl: Update script to get curl 7.52.1


---

Summary of changes:
 Help/release/dev/update-curl.rst   |6 +
 Tests/CMakeTests/FileDownloadBadHashTest.cmake.in  |5 +-
 Tests/CMakeTests/FileDownloadTest.cmake.in |5 +-
 Tests/CMakeTests/FileUploadTest.cmake.in   |5 +-
 Tests/RunCMake/file/DOWNLOAD-hash-mismatch.cmake   |5 +-
 Tests/RunCMake/file/DOWNLOAD-unused-argument.cmake |5 +-
 Tests/RunCMake/file/UPLOAD-unused-argument.cmake   |5 +-
 Utilities/Scripts/update-curl.bash |2 +-
 Utilities/cmcurl/CMake/OtherTests.cmake|   25 +-
 Utilities/cmcurl/CMakeLists.txt|8 +-
 Utilities/cmcurl/include/curl/curl.h   |   84 +-
 Utilities/cmcurl/include/curl/curlver.h|8 +-
 Utilities/cmcurl/include/curl/easy.h   |4 +-
 Utilities/cmcurl/include/curl/stdcheaders.h|6 +-
 Utilities/cmcurl/include/curl/typecheck-gcc.h  |   55 +-
 Utilities/cmcurl/lib/Makefile.inc  |4 +-
 Utilities/cmcurl/lib/asyn-ares.c   |4 +-
 Utilities/cmcurl/lib/asyn-thread.c |   24 +-
 Utilities/cmcurl/lib/conncache.c   |6 +-
 Utilities/cmcurl/lib/connect.c |   98 ++-
 Utilities/cmcurl/lib/connect.h |   13 +-
 Utilities/cmcurl/lib/content_encoding.c|   23 +-
 Utilities/cmcurl/lib/cookie.c  |   10 +-
 Utilities/cmcurl/lib/curl_addrinfo.c   |   34 +-
 Utilities/cmcurl/lib/curl_addrinfo.h   |2 +-
 Utilities/cmcurl/lib/curl_endian.c |   18 +-
 Utilities/cmcurl/lib/curl_endian.h |   18 +-
 Utilities/cmcurl/lib/curl_gethostname.c|8 +-
 Utilities/cmcurl/lib/curl_gssapi.c |2 +-
 Utilities/cmcurl/lib/curl_hmac.h   |   26 +-
 Utilities/cmcurl/lib/curl_ntlm_core.c  |2 +-
 Utilities/cmcurl/lib/curl_ntlm_wb.c|   13 +-
 Utilities/cmcurl/lib/curl_sasl.c   |   20 +-
 Utilities/cmcurl/lib/curl_sec.h|   16 +-
 Utilities/cmcurl/lib/curl_setup.h  |4 +-
 Utilities/cmcurl/lib/curl_threads.c|5 +-
 Utilities/cmcurl/lib/curl_threads.h|5 +-
 Utilities/cmcurl/lib/easy.c|2 +
 Utilities/cmcurl/lib/escape.c  |9 +-
 Utilities/cmcurl/lib/file.c|2 +-
 Utilities/cmcurl/lib/formdata.c|   46 +-
 Utilities/cmcurl/lib/formdata.h|2 +-
 Utilities/cmcurl/lib/ftp.c |  196 ++---
 Utilities/cmcurl/lib/ftp.h |2 +-
 Utilities/cmcurl/lib/ftplistparser.c   |8 +-
 Utilities/cmcurl/lib/getinfo.c |   29 +-
 Utilities/cmcurl/lib/hash.c|6 +-
 Utilities/cmcurl/lib/hash.h|   15 +-
 Utilities/cmcurl/lib/hmac.c|   10 +-
 Utilities/cmcurl/lib/hostcheck.c   |9 +-
 Utilities/cmcurl/lib/hostip.c  |4 +-
 Utilities/cmcurl/lib/hostip.h  |8 +-
 Utilities/cmcurl/lib/hostip4.c |2 +-
 Utilities/cmcurl/lib/http.c 

[Cmake-commits] CMake branch, next, updated. v3.8.0-rc1-65-gf78dfcf

2017-02-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  f78dfcfd57e10ab8f2d020bfbc462e535918bec0 (commit)
   via  d4da4755cdab41679ae7c2fa6ef2984a2d6837ec (commit)
   via  14c771530a12feb4f92fb0ab466b40ff68997b05 (commit)
  from  c8333e08fed572086f0e0fa9694f4ff75a3c9127 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=f78dfcfd57e10ab8f2d020bfbc462e535918bec0
commit f78dfcfd57e10ab8f2d020bfbc462e535918bec0
Merge: c8333e0 d4da475
Author: Brad King 
AuthorDate: Fri Feb 10 13:10:31 2017 -0500
Commit: CMake Topic Stage 
CommitDate: Fri Feb 10 13:10:31 2017 -0500

Merge topic 'update-curl' into next

d4da4755 Help: Add notes for topic 'update-curl'
14c77153 Tests: Fix `file://` URLs given to curl


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=d4da4755cdab41679ae7c2fa6ef2984a2d6837ec
commit d4da4755cdab41679ae7c2fa6ef2984a2d6837ec
Author: Brad King 
AuthorDate: Tue Feb 7 14:36:49 2017 -0500
Commit: Brad King 
CommitDate: Fri Feb 10 13:10:07 2017 -0500

Help: Add notes for topic 'update-curl'

diff --git a/Help/release/dev/update-curl.rst b/Help/release/dev/update-curl.rst
new file mode 100644
index 000..852ad5a
--- /dev/null
+++ b/Help/release/dev/update-curl.rst
@@ -0,0 +1,6 @@
+update-curl
+---
+
+* The version of curl bundled with CMake no longer accepts URLs of the form
+  ``file://c:/...`` on Windows due to a change in upstream curl 7.52.  Use
+  the form ``file:///c:/...`` instead to work on all versions.

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=14c771530a12feb4f92fb0ab466b40ff68997b05
commit 14c771530a12feb4f92fb0ab466b40ff68997b05
Author: Brad King 
AuthorDate: Tue Feb 7 14:25:49 2017 -0500
Commit: Brad King 
CommitDate: Fri Feb 10 13:10:07 2017 -0500

Tests: Fix `file://` URLs given to curl

Since upstream curl commit curl-7_52_0~131 (URL-parser: for
file://[host]/ URLs, the [host] must be localhost, 2016-11-11) we can no
longer use URLs of the form `file://c:/...` on Windows.  These worked
only accidentally before.  Use `file:///c:/...` instead.

diff --git a/Tests/CMakeTests/FileDownloadBadHashTest.cmake.in 
b/Tests/CMakeTests/FileDownloadBadHashTest.cmake.in
index 4a47c06..64b45ed 100644
--- a/Tests/CMakeTests/FileDownloadBadHashTest.cmake.in
+++ b/Tests/CMakeTests/FileDownloadBadHashTest.cmake.in
@@ -1,4 +1,7 @@
-set(url "file://@CMAKE_CURRENT_SOURCE_DIR@/FileDownloadInput.png")
+if(NOT "@CMAKE_CURRENT_SOURCE_DIR@" MATCHES "^/")
+  set(slash /)
+endif()
+set(url "file://${slash}@CMAKE_CURRENT_SOURCE_DIR@/FileDownloadInput.png")
 set(dir "@CMAKE_CURRENT_BINARY_DIR@/downloads")
 
 file(DOWNLOAD
diff --git a/Tests/CMakeTests/FileDownloadTest.cmake.in 
b/Tests/CMakeTests/FileDownloadTest.cmake.in
index 83ade2b..f6d9ad9 100644
--- a/Tests/CMakeTests/FileDownloadTest.cmake.in
+++ b/Tests/CMakeTests/FileDownloadTest.cmake.in
@@ -1,4 +1,7 @@
-set(url "file://@CMAKE_CURRENT_SOURCE_DIR@/FileDownloadInput.png")
+if(NOT "@CMAKE_CURRENT_SOURCE_DIR@" MATCHES "^/")
+  set(slash /)
+endif()
+set(url "file://${slash}@CMAKE_CURRENT_SOURCE_DIR@/FileDownloadInput.png")
 set(dir "@CMAKE_CURRENT_BINARY_DIR@/downloads")
 
 message(STATUS "FileDownload:1")
diff --git a/Tests/CMakeTests/FileUploadTest.cmake.in 
b/Tests/CMakeTests/FileUploadTest.cmake.in
index 8577aef..9e22909 100644
--- a/Tests/CMakeTests/FileUploadTest.cmake.in
+++ b/Tests/CMakeTests/FileUploadTest.cmake.in
@@ -10,7 +10,10 @@ endif()
 file(MAKE_DIRECTORY "@CMAKE_CURRENT_BINARY_DIR@/uploads")
 
 set(filename "@CMAKE_CURRENT_SOURCE_DIR@/FileDownloadInput.png")
-set(urlbase "file://@CMAKE_CURRENT_BINARY_DIR@/uploads")
+if(NOT "@CMAKE_CURRENT_BINARY_DIR@" MATCHES "^/")
+  set(slash /)
+endif()
+set(urlbase "file://${slash}@CMAKE_CURRENT_BINARY_DIR@/uploads")
 
 message(STATUS "FileUpload:1")
 file(UPLOAD
diff --git a/Tests/RunCMake/file/DOWNLOAD-hash-mismatch.cmake 
b/Tests/RunCMake/file/DOWNLOAD-hash-mismatch.cmake
index ca72692..a91b217 100644
--- a/Tests/RunCMake/file/DOWNLOAD-hash-mismatch.cmake
+++ b/Tests/RunCMake/file/DOWNLOAD-hash-mismatch.cmake
@@ -1,5 +1,8 @@
+if(NOT "${CMAKE_CURRENT_SOURCE_DIR}" MATCHES "^/")
+  set(slash /)
+endif()
 file(DOWNLOAD
-  "file://${CMAKE_CURRENT_SOURCE_DIR}/DOWNLOAD-hash-mismatch.txt"
+  "file://${slash}${CMAKE_CURRENT_SOURCE_DIR}/DOWNLOAD-hash-mismatch.txt"
   ${CMAKE_CURRENT_BINARY_DIR}/hash-mismatch.txt
   EXPECTED_HASH SHA1=0123456789abcdef0123456789abcdef01234567
   STATUS status
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.8.0-rc1-59-g8068f44

2017-02-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  8068f441f6ae65bec7d0cf3ba50cbbf97f2087b4 (commit)
   via  46c6489850ca9029bb75d17ed652563fc58a0082 (commit)
   via  ada0bc21f42e25882ddf5a8aab10eaf3ea7e0b89 (commit)
   via  90a55bb1d2b18d14eec3c972e1b045205acfd708 (commit)
  from  f7993cbeaa9d770646a97d7abeaa9b46087dfe59 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=8068f441f6ae65bec7d0cf3ba50cbbf97f2087b4
commit 8068f441f6ae65bec7d0cf3ba50cbbf97f2087b4
Merge: f7993cb 46c6489
Author: Brad King 
AuthorDate: Fri Feb 10 11:32:32 2017 -0500
Commit: Brad King 
CommitDate: Fri Feb 10 11:32:32 2017 -0500

Merge branch 'master' into next


---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.8.0-rc1-55-gf7993cb

2017-02-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  f7993cbeaa9d770646a97d7abeaa9b46087dfe59 (commit)
   via  30abf145fd48f50c26ee7553fd2512e59be97f25 (commit)
   via  97917900d146acd55a7e453f477c52cd2e816eb3 (commit)
   via  971384c28759ad042624bda3893be6fdb1795591 (commit)
  from  e70392430de41387679706c6c1b01cc74b261aa5 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=f7993cbeaa9d770646a97d7abeaa9b46087dfe59
commit f7993cbeaa9d770646a97d7abeaa9b46087dfe59
Merge: e703924 30abf14
Author: Brad King 
AuthorDate: Fri Feb 10 11:20:52 2017 -0500
Commit: CMake Topic Stage 
CommitDate: Fri Feb 10 11:20:52 2017 -0500

Merge topic 'sphinx-1.4' into next

30abf145 Help: Fix cmake code block warnings produced by Sphinx 1.4
97917900 Utilities/Sphinx: Port qthelp css workaround to Sphinx 1.4
971384c2 Utilities/Sphinx: Port cmake extension to Sphinx 1.4


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=30abf145fd48f50c26ee7553fd2512e59be97f25
commit 30abf145fd48f50c26ee7553fd2512e59be97f25
Author: Brad King 
AuthorDate: Fri Feb 10 09:55:46 2017 -0500
Commit: Brad King 
CommitDate: Fri Feb 10 10:43:30 2017 -0500

Help: Fix cmake code block warnings produced by Sphinx 1.4

Some of our "cmake" code blocks do not use fully valid CMake syntax
because they have placeholders for human reference.  Sphinx has
never been able to properly lex and highlight these, but now warns.
Fix each block's syntax or change to a non-cmake block as appropriate.

diff --git a/Help/command/if.rst b/Help/command/if.rst
index 0941029..2a087d0 100644
--- a/Help/command/if.rst
+++ b/Help/command/if.rst
@@ -9,17 +9,17 @@ Conditionally execute a group of commands.
# then section.
COMMAND1(ARGS ...)
COMMAND2(ARGS ...)
-   ...
+   #...
  elseif(expression2)
# elseif section.
COMMAND1(ARGS ...)
COMMAND2(ARGS ...)
-   ...
+   #...
  else(expression)
# else section.
COMMAND1(ARGS ...)
COMMAND2(ARGS ...)
-   ...
+   #...
  endif(expression)
 
 Evaluates the given expression.  If the result is true, the commands
diff --git a/Help/manual/cmake-developer.7.rst 
b/Help/manual/cmake-developer.7.rst
index 46b922b..f77d8c0 100644
--- a/Help/manual/cmake-developer.7.rst
+++ b/Help/manual/cmake-developer.7.rst
@@ -540,7 +540,7 @@ a :ref:`Line Comment` block of the form:
 
 or a :ref:`Bracket Comment` of the form:
 
-.. code-block:: cmake
+::
 
  #[[.rst:
  
@@ -558,7 +558,7 @@ All such comments must start with ``#`` in the first column.
 
 For example, a ``Modules/Findxxx.cmake`` module may contain:
 
-.. code-block:: cmake
+::
 
  # Distributed under the OSI-approved BSD 3-Clause License.  See accompanying
  # file Copyright.txt or https://cmake.org/licensing for details.
diff --git a/Help/manual/cmake-language.7.rst b/Help/manual/cmake-language.7.rst
index 41542c9..ba0b30f 100644
--- a/Help/manual/cmake-language.7.rst
+++ b/Help/manual/cmake-language.7.rst
@@ -255,7 +255,7 @@ invocation as exactly one argument.
 
 For example:
 
-.. code-block:: cmake
+::
 
  message("This is a quoted argument containing multiple lines.
  This is always one argument even though it contains a ; character.
@@ -421,7 +421,7 @@ A ``#`` immediately followed by a `Bracket Argument`_ forms 
a
 
 For example:
 
-.. code-block:: cmake
+::
 
  #[[This is a bracket comment.
  It runs until the close bracket.]]
diff --git a/Modules/CMakePackageConfigHelpers.cmake 
b/Modules/CMakePackageConfigHelpers.cmake
index 3210222..90c2a57 100644
--- a/Modules/CMakePackageConfigHelpers.cmake
+++ b/Modules/CMakePackageConfigHelpers.cmake
@@ -40,7 +40,7 @@
 #set(FOO_INCLUDE_DIR   "@CMAKE_INSTALL_FULL_INCLUDEDIR@" )
 #set(FOO_DATA_DIR   "@CMAKE_INSTALL_PREFIX@/@RELATIVE_DATA_INSTALL_DIR@" )
 #set(FOO_ICONS_DIR   "@CMAKE_INSTALL_PREFIX@/share/icons" )
-#...logic to determine installedPrefix from the own location...
+##...logic to determine installedPrefix from the own location...
 #set(FOO_CONFIG_DIR  "${installedPrefix}/@CONFIG_INSTALL_DIR@" )
 #
 # All 4 options shown above are not sufficient, since the first 3 hardcode the
@@ -174,7 +174,7 @@
 #set(INCLUDE_INSTALL_DIR include/ ... CACHE )
 #set(LIB_INSTALL_DIR lib/ ... CACHE )
 #set(SYSCONFIG_INSTALL_DIR etc/foo/ ... CACHE )
-#...
+##...
 #include(CMakePackageConfigHelpers)
 #configure_package_config_file(FooConfig.cmake.in
 #  ${CMAKE_CURRENT_BINARY_DIR}/FooConfig.cmake
@@ -190,7 +190,7 @@
 #
 # ``FooConfig.cmake.in``:
 #
-# .. code-block:: cmake
+# ::
 #
 #set(FOO_VERSION x.y.z)
 #.
diff --git a/Tests/RunCMake/file/DOWNLOAD-unused-argument.cmake 
b/Tests/RunCMake/file/DOWNLOAD-unused-argument.cmake
index 2e3fbe1..2fa548

[Cmake-commits] CMake branch, next, updated. v3.8.0-rc1-62-gc8333e0

2017-02-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  c8333e08fed572086f0e0fa9694f4ff75a3c9127 (commit)
   via  b628a1dcb0548c56477e25b0c992d9929562502d (commit)
   via  d73d9d01b996a17788362c0a12dfe28d9948b29d (commit)
  from  8068f441f6ae65bec7d0cf3ba50cbbf97f2087b4 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=c8333e08fed572086f0e0fa9694f4ff75a3c9127
commit c8333e08fed572086f0e0fa9694f4ff75a3c9127
Merge: 8068f44 b628a1d
Author: Brad King 
AuthorDate: Fri Feb 10 12:36:50 2017 -0500
Commit: CMake Topic Stage 
CommitDate: Fri Feb 10 12:36:50 2017 -0500

Merge topic 'update-kwsys' into next

b628a1dc Merge branch 'upstream-KWSys' into update-kwsys
d73d9d01 KWSys 2017-02-10 (06efe24e)


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=b628a1dcb0548c56477e25b0c992d9929562502d
commit b628a1dcb0548c56477e25b0c992d9929562502d
Merge: 46c6489 d73d9d0
Author: Brad King 
AuthorDate: Fri Feb 10 12:30:37 2017 -0500
Commit: Brad King 
CommitDate: Fri Feb 10 12:30:37 2017 -0500

Merge branch 'upstream-KWSys' into update-kwsys

* upstream-KWSys:
  KWSys 2017-02-10 (06efe24e)


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=d73d9d01b996a17788362c0a12dfe28d9948b29d
commit d73d9d01b996a17788362c0a12dfe28d9948b29d
Author: KWSys Upstream 
AuthorDate: Fri Feb 10 12:30:10 2017 -0500
Commit: Brad King 
CommitDate: Fri Feb 10 12:30:36 2017 -0500

KWSys 2017-02-10 (06efe24e)

Code extracted from:

https://gitlab.kitware.com/utils/kwsys.git

at commit 06efe24e4166911b7658f17164ade108ddfd35d0 (master).

Upstream Shortlog
-

Nicolás Bértolo (1):
  9c4230b7 SystemInformation: Fix counts of logical and physical cores

diff --git a/SystemInformation.cxx b/SystemInformation.cxx
index e01dcd7..fc1a752 100644
--- a/SystemInformation.cxx
+++ b/SystemInformation.cxx
@@ -35,8 +35,13 @@
 #include "SystemInformation.hxx.in"
 #endif
 
+#include 
+#include 
+#include 
 #include 
 #include 
+#include 
+#include 
 #include 
 #include 
 #include 
@@ -394,7 +399,6 @@ public:
 bool SupportsMP;
 bool HasMMXPlus;
 bool HasSSEMMX;
-bool SupportsHyperthreading;
 unsigned int LogicalProcessorsPerPhysical;
 int APIC_ID;
 CPUPowerManagement PowerManagement;
@@ -463,10 +467,9 @@ protected:
   unsigned int NumberOfLogicalCPU;
   unsigned int NumberOfPhysicalCPU;
 
-  int CPUCount(); // For windows
-  unsigned char LogicalCPUPerPhysicalCPU();
+  void CPUCountWindows();// For windows
   unsigned char GetAPICId(); // For windows
-  bool IsHyperThreadingSupported();
+  bool IsSMTSupported();
   static LongLong GetCyclesDifference(DELAY_FUNC, unsigned int); // For windows
 
   // For Linux and Cygwin, /proc/cpuinfo formats are slightly different
@@ -1542,7 +1545,7 @@ void SystemInformationImplementation::RunCPUCheck()
 RetrieveProcessorSerialNumber();
   }
 
-  this->CPUCount();
+  this->CPUCountWindows();
 
 #elif defined(__APPLE__)
   this->ParseSysCtl();
@@ -2090,16 +2093,10 @@ bool 
SystemInformationImplementation::RetrieveCPUFeatures()
 
   // Retrieve Intel specific extended features.
   if (this->ChipManufacturer == Intel) {
-this->Features.ExtendedFeatures.SupportsHyperthreading =
-  ((cpuinfo[3] & 0x1000) !=
-   0); // Intel specific: Hyperthreading --> Bit 28
-this->Features.ExtendedFeatures.LogicalProcessorsPerPhysical =
-  (this->Features.ExtendedFeatures.SupportsHyperthreading)
-  ? ((cpuinfo[1] & 0x00FF) >> 16)
-  : 1;
-
-if ((this->Features.ExtendedFeatures.SupportsHyperthreading) &&
-(this->Features.HasAPIC)) {
+bool SupportsSMT =
+  ((cpuinfo[3] & 0x1000) != 0); // Intel specific: SMT --> Bit 28
+
+if ((SupportsSMT) && (this->Features.HasAPIC)) {
   // Retrieve APIC information if there is one present.
   this->Features.ExtendedFeatures.APIC_ID =
 ((cpuinfo[1] & 0xFF00) >> 24);
@@ -3401,7 +3398,7 @@ bool 
SystemInformationImplementation::RetreiveInformationFromCpuInfoFile()
   fclose(fd);
   buffer.resize(fileSize - 2);
   // Number of logical CPUs (combination of multiple processors, multi-core
-  // and hyperthreading)
+  // and SMT)
   size_t pos = buffer.find("processor\t");
   while (pos != buffer.npos) {
 this->NumberOfLogicalCPU++;
@@ -3409,30 +3406,24 @@ bool 
SystemInformationImplementation::RetreiveInformationFromCpuInfoFile()
   }
 
 #ifdef __linux
-  // Find the largest physical id.
-  int maxId = -1;
+  // Count sockets.
+  std::set PhysicalIDs;
   std::string idc = thi

[Cmake-commits] CMake branch, master, updated. v3.8.0-rc1-27-g46c6489

2017-02-10 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  46c6489850ca9029bb75d17ed652563fc58a0082 (commit)
   via  30abf145fd48f50c26ee7553fd2512e59be97f25 (commit)
   via  97917900d146acd55a7e453f477c52cd2e816eb3 (commit)
   via  971384c28759ad042624bda3893be6fdb1795591 (commit)
  from  ada0bc21f42e25882ddf5a8aab10eaf3ea7e0b89 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=46c6489850ca9029bb75d17ed652563fc58a0082
commit 46c6489850ca9029bb75d17ed652563fc58a0082
Merge: ada0bc2 30abf14
Author: Brad King 
AuthorDate: Fri Feb 10 11:32:21 2017 -0500
Commit: CMake Topic Stage 
CommitDate: Fri Feb 10 11:32:21 2017 -0500

Merge topic 'sphinx-1.4'

30abf145 Help: Fix cmake code block warnings produced by Sphinx 1.4
97917900 Utilities/Sphinx: Port qthelp css workaround to Sphinx 1.4
971384c2 Utilities/Sphinx: Port cmake extension to Sphinx 1.4


---

Summary of changes:
 Help/command/if.rst|6 +++---
 Help/manual/cmake-developer.7.rst  |4 ++--
 Help/manual/cmake-language.7.rst   |4 ++--
 Modules/CMakePackageConfigHelpers.cmake|6 +++---
 Utilities/Sphinx/apply_qthelp_css_workaround.cmake |   14 +-
 Utilities/Sphinx/cmake.py  |8 ++--
 6 files changed, 25 insertions(+), 17 deletions(-)


hooks/post-receive